@@ -16,13 +16,11 @@ logger = logging.getLogger(__name__)
 
 
 class HuggingfaceDetectionModel(DetectionModel):
-    import torch
-
     def __init__(
         self,
         model_path: Optional[str] = None,
         model: Optional[Any] = None,
-        feature_extractor: Optional[Any] = None,
+        processor: Optional[Any] = None,
         config_path: Optional[str] = None,
         device: Optional[str] = None,
         mask_threshold: float = 0.5,
@@ -33,7 +31,7 @@ class HuggingfaceDetectionModel(DetectionModel):
         image_size: int = None,
     ):
 
-        self._feature_extractor = feature_extractor
+        self._processor = processor
         self._image_shapes = []
         super().__init__(
             model_path,
@@ -50,11 +48,11 @@ class HuggingfaceDetectionModel(DetectionModel):
 
     def check_dependencies(self):
         check_requirements(["torch", "transformers"])
-        ensure_package_minimum_version("transformers", "4.24.0")
+        ensure_package_minimum_version("transformers", "4.25.1")
 
     @property
-    def feature_extractor(self):
-        return self._feature_extractor
+    def processor(self):
+        return self._processor
 
     @property
     def image_shapes(self):
@@ -69,31 +67,28 @@ class HuggingfaceDetectionModel(DetectionModel):
 
     def load_model(self):
 
-        from transformers import AutoFeatureExtractor, AutoModelForObjectDetection
+        from transformers import AutoModelForObjectDetection, AutoProcessor
 
         model = AutoModelForObjectDetection.from_pretrained(self.model_path)
         if self.image_size is not None:
-            feature_extractor = AutoFeatureExtractor.from_pretrained(
-                self.model_path, size=self.image_size, do_resize=True
+            processor = AutoProcessor.from_pretrained(
+                self.model_path, size={"shortest_edge": self.image_size, "longest_edge": None}, do_resize=True
             )
         else:
-            feature_extractor = AutoFeatureExtractor.from_pretrained(self.model_path)
-        self.set_model(model, feature_extractor)
+            processor = AutoProcessor.from_pretrained(self.model_path)
+        self.set_model(model, processor)
 
-    def set_model(self, model: Any, feature_extractor: Any = None):
-        feature_extractor = feature_extractor or self.feature_extractor
-        if feature_extractor is None:
-            raise ValueError(f"'feature_extractor' is required to be set, got {feature_extractor}.")
-        elif (
-            "ObjectDetection" not in model.__class__.__name__
-            or "FeatureExtractor" not in feature_extractor.__class__.__name__
-        ):
+    def set_model(self, model: Any, processor: Any = None):
+        processor = processor or self.processor
+        if processor is None:
+            raise ValueError(f"'processor' is required to be set, got {processor}.")
+        elif "ObjectDetection" not in model.__class__.__name__ or "ImageProcessor" not in processor.__class__.__name__:
             raise ValueError(
-                "Given 'model' is not an ObjectDetectionModel or 'feature_extractor' is not a valid FeatureExtractor."
+                "Given 'model' is not an ObjectDetectionModel or 'processor' is not a valid ImageProcessor."
             )
         self.model = model
         self.model.to(self.device)
-        self._feature_extractor = feature_extractor
+        self._processor = processor
         self.category_mapping = self.model.config.id2label
 
     def perform_inference(self, image: Union[List, np.ndarray]):
@@ -110,7 +105,7 @@ class HuggingfaceDetectionModel(DetectionModel):
             raise RuntimeError("Model is not loaded, load it by calling .load_model()")
 
         with torch.no_grad():
-            inputs = self.feature_extractor(images=image, return_tensors="pt")
+            inputs = self.processor(images=image, return_tensors="pt")
             inputs["pixel_values"] = inputs.pixel_values.to(self.device)
             if hasattr(inputs, "pixel_mask"):
                 inputs["pixel_mask"] = inputs.pixel_mask.to(self.device)
@@ -122,9 +117,16 @@ class HuggingfaceDetectionModel(DetectionModel):
             self._image_shapes = [image.shape]
         self._original_predictions = outputs
 
-    def get_valid_predictions(
-        self, logits: torch.Tensor, pred_boxes: torch.Tensor
-    ) -> Tuple[torch.Tensor, torch.Tensor, torch.Tensor]:
+    def get_valid_predictions(self, logits, pred_boxes) -> Tuple:
+        """
+        Args:
+            logits: torch.Tensor
+            pred_boxes: torch.Tensor
+        Returns:
+            scores: torch.Tensor
+            cat_ids: torch.Tensor
+            boxes: torch.Tensor
+        """
         import torch
 
         probs = logits.softmax(-1)
